Introduction
============

The ``debops.auth`` role allows you to manage and configure basic user authentication and authorization on configured host, including setting up system groups with elevated privileges.

Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.6``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops.auth

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
